km3pipe.hardware.Detector
=========================

.. currentmodule:: km3pipe.hardware

.. autoclass:: Detector

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Detector.__init__
      ~Detector.domid2floor
      ~Detector.get_pmt
      ~Detector.pmt_with_id
      ~Detector.pmtid2omkey
      ~Detector.rescale
      ~Detector.reset_caches
      ~Detector.rotate_dom_by_yaw
      ~Detector.rotate_du_by_yaw
      ~Detector.translate_detector
      ~Detector.write
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Detector.ascii
      ~Detector.dom_ids
      ~Detector.dom_positions
      ~Detector.n_dus
      ~Detector.pmt_angles
      ~Detector.xy_positions
   
   